*********************************
MTfit Source Code
*********************************

Explore the source code for the :mod:`MTfit` module

Contents:
=================================

.. toctree::
   :maxdepth: 1

   MTfit.inversion <source-inversion>
   MTfit.algorithms <source-algorithms>
   MTfit.probability <source-probability>
   MTfit.sampling <source-sampling>
   MTfit.run <source-run>
   MTfit.utilities <source-utilities>
   MTfit.extensions <source-extensions>
   MTfit.convert <source-convert>
   MTfit.plot <source-plot>